==> elyra-1.3.1-py3-none-any.whl: package/lib/PipelineEditorWidget.d.ts <==
import { JupyterFrontEnd } from '@jupyterlab/application';
import { ReactWidget } from '@jupyterlab/apputils';
import { DocumentRegistry, ABCWidgetFactory, DocumentWidget } from '@jupyterlab/docregistry';
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
import { ServiceManager } from '@jupyterlab/services';
import { CommandRegistry } from '@lumino/commands';
import { Signal } from '@lumino/signaling';
import { Color } from '@material-ui/lab/Alert';
import 'carbon-components/css/carbon-components.min.css';
import '@elyra/canvas/dist/styles/common-canvas.min.css';
import '../style/canvas.css';
import * as React from 'react';
import { CanvasManager } from './canvas';
interface IValidationError {
    errorMessage: string;
    errorSeverity: Color;
}
export declare const commandIDs: {
    openPipelineEditor: string;
    openMetadata: string;
    openDocManager: string;
    newDocManager: string;
    submitNotebook: string;
    addFileToPipeline: string;
};
/**
 * Wrapper Class for Common Canvas React Component
 */
export declare class PipelineEditorWidget extends ReactWidget {
    shell: JupyterFrontEnd.IShell;
    commands: CommandRegistry;
    browserFactory: IFileBrowserFactory;
    context: DocumentRegistry.Context;
    serviceManager: ServiceManager;
    addFileToPipelineSignal: Signal<PipelineEditorFactory, any>;
    constructor(props: any);
    render(): React.ReactElement;
}
/**
 * A namespace for Pipeline.
 */
export declare namespace PipelineEditor {
    /**
     * The props for PipelineEditor.
     */
    interface IProps {
        shell: JupyterFrontEnd.IShell;
        commands: CommandRegistry;
        browserFactory: IFileBrowserFactory;
        widgetContext: DocumentRegistry.Context;
        serviceManager: ServiceManager;
        addFileToPipelineSignal: Signal<PipelineEditorFactory, any>;
        widgetId: string;
    }
    /**
     * The props for PipelineEditor.
     */
    interface IState {
        /**
         * Whether the properties dialog is visible.
         */
        showPropertiesDialog: boolean;
        /**
         * The form contents of the properties dialog.
         */
        propertiesInfo: any;
        showValidationError: boolean;
        validationError: IValidationError;
        /**
         * Whether pipeline is empty.
         */
        emptyPipeline: boolean;
    }
}
/**
 * Class for Common Canvas React Component
 */
export declare class PipelineEditor extends React.Component<PipelineEditor.IProps, PipelineEditor.IState> {
    shell: JupyterFrontEnd.IShell;
    commands: CommandRegistry;
    browserFactory: IFileBrowserFactory;
    canvasManager: CanvasManager;
    serviceManager: ServiceManager;
    canvasController: any;
    widgetContext: DocumentRegistry.Context;
    widgetId: string;
    addFileToPipelineSignal: Signal<PipelineEditorFactory, any>;
    position: number;
    node: React.RefObject<HTMLDivElement>;
    propertiesInfo: any;
    propertiesController: any;
    constructor(props: any);
    render(): React.ReactElement;
    updateModel(): void;
    initPropertiesInfo(): Promise<void>;
    openPropertiesDialog(source: any): void;
    applyPropertyChanges(propertySet: any, appData: any): void;
    closePropertiesDialog(): void;
    propertiesControllerHandler(propertiesController: any): void;
    propertiesActionHandler(id: string, appData: any, data: any): void;
    contextMenuHandler(source: any, defaultMenu: any): any;
    clickActionHandler(source: any): void;
    nodesConnected(sourceNode: string, targetNode: string, links: any[]): boolean;
    beforeEditActionHandler(data: any): any;
    editActionHandler(data: any): void;
    tipHandler(tipType: string, data: any): any;
    handleAddFileToPipelineCanvas(x?: number, y?: number): Promise<any>;
    handleOpenFile(selectedNodes: any): void;
    handleExportPipeline(): Promise<void>;
    handleOpenPipeline(): Promise<void>;
    setAndVerifyPipelineFlow(pipelineJson: any): Promise<void>;
    /**
     * Adds an error decoration if a node has any invalid properties.
     *
     * @param node - canvas node object to validate
     *
     * @returns true if the node is valid.
     */
    validateNode(node: any, pipelineId: string): Promise<boolean>;
    /**
     * Validates the properties of a given node.
     *
     * @param node: node to check properties for
     *
     * @returns a warning message to display in the tooltip
     * if there are invalid properties. If there are none,
     * returns null.
     */
    validateProperties(node: any): Promise<string>;
    /**
     * Validates the properties of all nodes in the pipeline.
     * Updates the decorations / style of all nodes.
     *
     * @returns null if all nodes are valid, error message if
     * invalid.
     */
    validateAllNodes(): Promise<string>;
    /**
     * Validates all links in the pipeline.
     * Updates the decorations / style of links.
     *
     * @returns null if pipeline is valid, error message if not.
     */
    validateAllLinks(): string;
    /**
     * Validates all links and nodes in the pipeline.
     * Updates the decorations / style of links and nodes.
     *
     * @returns null if pipeline is valid, error message if not.
     */
    validatePipeline(): Promise<string>;
    handleRunPipeline(): Promise<void>;
    handleSavePipeline(): void;
    handleClearPipeline(data: any): Promise<any>;
    handleOpenRuntimes(): void;
    handleClosePipeline(): void;
    componentDidMount(): void;
    componentWillUnmount(): void;
    /**
     * Handle the DOM events.
     *
     * @param event - The DOM event.
     */
    handleEvent(event: Event): void;
}
export declare class PipelineEditorFactory extends ABCWidgetFactory<DocumentWidget> {
    shell: JupyterFrontEnd.IShell;
    commands: CommandRegistry;
    browserFactory: IFileBrowserFactory;
    serviceManager: ServiceManager;
    addFileToPipelineSignal: Signal<this, any>;
    constructor(options: any);
    protected createNewWidget(context: DocumentRegistry.Context): DocumentWidget;
}
export {};

==> elyra-2.1.0-py3-none-any.whl: package/lib/PipelineEditorWidget.d.ts <==
import { JupyterFrontEnd } from '@jupyterlab/application';
import { ReactWidget } from '@jupyterlab/apputils';
import { DocumentRegistry, ABCWidgetFactory, DocumentWidget } from '@jupyterlab/docregistry';
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
import { ServiceManager } from '@jupyterlab/services';
import { CommandRegistry } from '@lumino/commands';
import { Signal } from '@lumino/signaling';
import { Color } from '@material-ui/lab/Alert';
import 'carbon-components/css/carbon-components.min.css';
import '@elyra/canvas/dist/styles/common-canvas.min.css';
import '../style/canvas.css';
import * as React from 'react';
import { CanvasManager } from './canvas';
interface IValidationError {
    errorMessage: string;
    errorSeverity: Color;
}
export declare const commandIDs: {
    openPipelineEditor: string;
    openMetadata: string;
    openDocManager: string;
    newDocManager: string;
    submitScript: string;
    submitNotebook: string;
    addFileToPipeline: string;
};
/**
 * Wrapper Class for Common Canvas React Component
 */
export declare class PipelineEditorWidget extends ReactWidget {
    shell: JupyterFrontEnd.IShell;
    commands: CommandRegistry;
    browserFactory: IFileBrowserFactory;
    context: DocumentRegistry.Context;
    serviceManager: ServiceManager;
    addFileToPipelineSignal: Signal<PipelineEditorFactory, any>;
    constructor(props: any);
    render(): React.ReactElement;
}
/**
 * A namespace for Pipeline.
 */
export declare namespace PipelineEditor {
    /**
     * The props for PipelineEditor.
     */
    interface IProps {
        shell: JupyterFrontEnd.IShell;
        commands: CommandRegistry;
        browserFactory: IFileBrowserFactory;
        widgetContext: DocumentRegistry.Context;
        serviceManager: ServiceManager;
        addFileToPipelineSignal: Signal<PipelineEditorFactory, any>;
        widgetId: string;
    }
    /**
     * The props for PipelineEditor.
     */
    interface IState {
        /**
         * Whether the properties dialog is visible.
         */
        showPropertiesDialog: boolean;
        /**
         * The form contents of the properties dialog.
         */
        propertiesInfo: any;
        showValidationError: boolean;
        validationError: IValidationError;
        /**
         * Whether pipeline is empty.
         */
        emptyPipeline: boolean;
    }
}
/**
 * Class for Common Canvas React Component
 */
export declare class PipelineEditor extends React.Component<PipelineEditor.IProps, PipelineEditor.IState> {
    shell: JupyterFrontEnd.IShell;
    commands: CommandRegistry;
    browserFactory: IFileBrowserFactory;
    canvasManager: CanvasManager;
    serviceManager: ServiceManager;
    canvasController: any;
    widgetContext: DocumentRegistry.Context;
    widgetId: string;
    addFileToPipelineSignal: Signal<PipelineEditorFactory, any>;
    position: number;
    node: React.RefObject<HTMLDivElement>;
    propertiesInfo: any;
    propertiesController: any;
    CommonProperties: any;
    constructor(props: any);
    render(): React.ReactElement;
    updateModel(): void;
    initPropertiesInfo(): Promise<void>;
    openPropertiesDialog(source: any): void;
    applyPropertyChanges(propertySet: any, appData: any, additionalData: any): void;
    closePropertiesDialog(): void;
    propertiesControllerHandler(propertiesController: any): void;
    propertiesActionHandler(id: string, appData: any, data: any): void;
    contextMenuHandler(source: any, defaultMenu: any): any;
    clickActionHandler(source: any): Promise<void>;
    beforeEditActionHandler(data: any): any;
    editActionHandler(data: any): void;
    tipHandler(tipType: string, data: any): any;
    handleAddFileToPipelineCanvas(x?: number, y?: number): Promise<any>;
    handleOpenFile(selectedNodes: any): void;
    cleanNullProperties(): void;
    handleExportPipeline(): Promise<void>;
    handleOpenPipeline(): Promise<void>;
    setAndVerifyPipelineFlow(pipelineJson: any): Promise<void>;
    /**
     * Adds an error decoration if a node has any invalid properties.
     *
     * @param node - canvas node object to validate
     *
     * @returns true if the node is valid.
     */
    validateNode(node: any, pipelineId: string): Promise<boolean>;
    /**
     * Validates the properties of a given node.
     *
     * @param node: node to check properties for
     *
     * @returns a warning message to display in the tooltip
     * if there are invalid properties. If there are none,
     * returns null.
     */
    validateProperties(node: any): Promise<string>;
    /**
     * Validates the properties of all nodes in the pipeline.
     * Updates the decorations / style of all nodes.
     *
     * @returns null if all nodes are valid, error message if
     * invalid.
     */
    validateAllNodes(): Promise<string>;
    /**
     * Validates all links in the pipeline.
     * Updates the decorations / style of links.
     *
     * @returns null if pipeline is valid, error message if not.
     */
    validateAllLinks(): string;
    /**
     * Validates all links and nodes in the pipeline.
     * Updates the decorations / style of links and nodes.
     *
     * @returns null if pipeline is valid, error message if not.
     */
    validatePipeline(): Promise<string>;
    /**
     * Displays a dialog containing a JSON error
     */
    handleJSONError(error: any): void;
    handleRunPipeline(): Promise<void>;
    handleSavePipeline(): void;
    handleClearPipeline(data: any): Promise<any>;
    handleOpenRuntimes(): void;
    handleClosePipeline(): void;
    componentDidMount(): void;
    componentDidUpdate(): void;
}
export declare class PipelineEditorFactory extends ABCWidgetFactory<DocumentWidget> {
    shell: JupyterFrontEnd.IShell;
    commands: CommandRegistry;
    browserFactory: IFileBrowserFactory;
    serviceManager: ServiceManager;
    addFileToPipelineSignal: Signal<this, any>;
    constructor(options: any);
    protected createNewWidget(context: DocumentRegistry.Context): DocumentWidget;
}
export {};
